﻿using System;
using System.Text;
using System.Collections.Generic;
using System.Linq;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using Telerik.OpenAccess.Metadata;

namespace OpenAccessTests
{
    /// <summary>
    /// Summary description for MetadataTests
    /// </summary>
    [TestClass]
    public class MetadataTests
    {
        private MetadataContainer container;

        public MetadataContainer Container
        {
            get { return this.container; }
        }

        private TestContext testContextInstance;

        /// <summary>
        ///Gets or sets the test context which provides
        ///information about and functionality for the current test run.
        ///</summary>
        public TestContext TestContext
        {
            get
            {
                return testContextInstance;
            }
            set
            {
                testContextInstance = value;
            }
        }

        #region Additional test attributes
        //
        // You can use the following additional attributes as you write your tests:
        //
        // Use ClassInitialize to run code before running the first test in the class
        // [ClassInitialize()]
        // public static void MyClassInitialize(TestContext testContext) { }
        //
        // Use ClassCleanup to run code after all tests in a class have run
        // [ClassCleanup()]
        // public static void MyClassCleanup() { }
        //
        // Use TestInitialize to run code before running each test 
        [TestInitialize()]
        public void MyTestInitialize() 
        {
            XmlMetadataSource source = XmlMetadataSource.FromAssemblyResource("NorthwindModel.rlinq");
            this.container = source.GetModel();
        }
        //
        // Use TestCleanup to run code after each test has run
        [TestCleanup()]
        public void MyTestCleanup() 
        {
            this.container = null;
        }
        //
        #endregion

        [TestMethod]
        public void CheckIfPrimitivePropertyExists()
        {
            MetaPersistentType metaPersistentType = this.Container.PersistentTypes.FirstOrDefault(pt => pt.Name.Equals("Category"));
            Assert.IsNotNull(metaPersistentType);

            string propertyName = "CategoryName";
            MetaMember metaMember = metaPersistentType.Members.FirstOrDefault(mm => mm.PropertyName.Equals(propertyName));
            Assert.IsNotNull(metaMember);
            Assert.IsInstanceOfType(metaMember, typeof(MetaPrimitiveMember));
            // you could add more asserts here
        }

        [TestMethod]
        public void CheckIfCollectionExists()
        {
            MetaPersistentType metaPersistentType = this.Container.PersistentTypes.FirstOrDefault(pt => pt.Name.Equals("Category"));
            Assert.IsNotNull(metaPersistentType);

            string propertyName = "Products";
            MetaMember metaMember = metaPersistentType.Members.FirstOrDefault(mm => mm.PropertyName.Equals(propertyName));
            Assert.IsNotNull(metaMember);
            Assert.IsInstanceOfType(metaMember, typeof(MetaNavigationMember));
            // you could add more asserts here
        }
    }
}
